@@ -125,7 +125,7 @@ $string['notcalledfromserver'] = 'Should not be called from the web server!';
 $string['noupdatestobedone'] = "No updates to be done\n";
 $string['nouserentriestoremove'] = "No user entries to be removed\n";
 $string['nouserentriestorevive'] = "No user entries to be revived\n";
-$string['nouserstobeadded'] = "No users to be added\n";
+$string['nouserstobeadded'] = 'No user entries to be added';
 $string['ntlmsso_attempting'] = 'Attempting Single Sign On via NTLM...';
 $string['ntlmsso_failed'] = 'Auto-login failed, try the normal login page...';
 $string['ntlmsso_isdisabled'] = 'NTLM SSO is disabled.';
