@@ -1,5 +1,4 @@
 <?php
-
 // This file is part of Moodle - http://moodle.org/
 //
 // Moodle is free software: you can redistribute it and/or modify
@@ -18,14 +17,14 @@
 /**
  * TinyMCE text editor integration version file.
  *
- * @package    editor
- * @subpackage tinymce
+ * @package    editor_tinymce
  * @copyright  2009 Petr Skoda (http://skodak.org)
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 
 defined('MOODLE_INTERNAL') || die();
 
-$plugin->version  = 2010093000;
-$plugin->requires = 2010070300;
-$plugin->release  = '3.4.2';
+$plugin->version   = 2013110602;        // The current plugin version (Date: YYYYMMDDXX)
+$plugin->requires  = 2013110500;        // Requires this Moodle version
+$plugin->component = 'editor_tinymce';  // Full name of the plugin (used for diagnostics)
+$plugin->release   = '3.5.10';           // This is NOT a directory name, see lib.php if you need to know where is the editor code!
