@@ -191,7 +191,7 @@ M.core.dock.fixTitleOrientation = function(title, text) {
     }
 
     // We need to fix a font-size - sorry theme designers.
-    test = Y.Node.create('<h2><span class="transform-test-node" style="font-size:'+fontsize+';">'+text+'</span></h2>');
+    test = Y.Node.create('<h2 class="transform-test-heading"><span class="transform-test-node" style="font-size:'+fontsize+';">'+text+'</span></h2>');
     BODY.insert(test, 0);
     width = test.one('span').get('offsetWidth') * 1.2;
     height = test.one('span').get('offsetHeight');
@@ -202,12 +202,10 @@ M.core.dock.fixTitleOrientation = function(title, text) {
 
     // Move the title into position
     title.setStyles({
-        'margin' : '0',
-        'padding' : '0',
         'position' : 'relative',
         'fontSize' : fontsize,
         'width' : width,
-        'top' : width/2
+        'top' : (width - height)/2
     });
 
     // Positioning is different when in RTL mode.
@@ -758,14 +756,18 @@ DOCK.prototype = {
             showregions = false,
             i;
         // First look for understood regions.
-        Y.all(SELECTOR.blockregion).each(function(){
+        Y.all(SELECTOR.blockregion).each(function(region){
             var regionname = region.getData('blockregion');
             if (region.all('.block').size() > 0) {
                 populatedblockregions++;
                 BODY.addClass('used-region-'+regionname);
                 BODY.removeClass('empty-region-'+regionname);
-            } else {
+                BODY.removeClass('docked-region-'+regionname);
+            } else if (region.all('.block_dock_placeholder').size() > 0) {
+                // There are no blocks in the region but there are placeholders.
+                // All blocks in this region have been docked.
                 BODY.addClass('empty-region-'+regionname);
+                BODY.addClass('docked-region-'+regionname);
                 BODY.removeClass('used-region-'+regionname);
             }
         });
@@ -978,7 +980,7 @@ DOCK.prototype = {
         }
 
         if (this.get('position') === 'right') {
-            panel.get('node').setStyle('left', -panel.get('offsetWidth')+'px');
+            panel.get('node').setStyle('left', '-' + panel.get('node').get('offsetWidth') + 'px');
 
         } else if (this.get('position') === 'top') {
             dockx = this.get('dockNode').getX();
